[−][src]Crate botw_utils
Modules
| extensions | Contains arrays of file extensions used by BOTW for SARC, AAMP, and BYML files |
| hashes |
Functions
| get_canon_name | Convert a path relative to a BOTW content root into a canonical resource path. Example: |
| get_canon_name_without_root | Convert a BOTW game resource path without a root folder into a canonical resource path. Most useful for normalizing paths to resources inside of SARC archives. Example: |