[][src]Module botw_utils::hashes

Structs

StockHashTable

A struct wrapping a hash table for stock BOTW files with a few convenience methods

Enums

Platform

Platform enum for Wii U or Switch copy of BOTW

Functions

get_hash_table

Gets a hash table of stock BOTW 1.5.0 (for Wii U) or stock 1.6.0 (for Switch) game files and possible hashes for them. These include, where applicable, the original hash and variants created by processing unmodified files with common libraries and tools.