[−][src]Function botw_utils::hashes::get_hash_table
pub fn get_hash_table(platform: &Platform) -> HashMap<&'static str, Vec<u64>>
Gets a hash table of stock BOTW 1.5.0 (for Wii U) or stock 1.6.0 (for Switch) game files and possible hashes for them. These include, where applicable, the original hash and variants created by processing unmodified files with common libraries and tools.